strawboss - local procfile runner
=================================

.. image:: https://img.shields.io/pypi/pyversions/strawboss.svg
   :target: Supported Python versions
   :alt: https://pypi.python.org/pypi/strawboss

.. image:: https://pypip.in/v/strawboss/badge.png
   :target: https://badge.fury.io/py/strawboss.svg
   :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/strawboss/badge/?version=latest
   :target: http://strawboss.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/strawboss.svg
   :alt: Released under MIT license

.. image:: https://img.shields.io/travis/smartmob-project/strawboss.svg
   :target: https://travis-ci.org/smartmob-project/strawboss
   :alt: Current build status

.. image:: https://coveralls.io/repos/smartmob-project/strawboss/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/smartmob-project/strawboss?branch=master
   :alt: Current code coverage

Description
-----------

This project is a command-line interface and a collections of utilities for
locally running all programs in a distributed system using a ``Procfile``.  See
`Smartmob RFC 1 - Procfile
<http://smartmob-rfc.readthedocs.org/en/latest/1-procfile.html>`_.

Documentation
-------------

You can find the documentation on ReadTheDocs:

- latest_

.. _latest: http://strawboss.readthedocs.org/en/latest/

Contributing
------------

We welcome pull requests!  Please open up an issue on the `issue tracker`_ to
discuss, fork the project and then send in a pull request :-)

Feel free to add yourself to the ``CONTRIBUTORS`` file on your first pull
request!

.. _`issue tracker`: https://github.com/smartmob/strawboss/issues

License
-------

The source code and documentation is made available under an MIT license.  See
``LICENSE`` file for details.
